
@echo off
echo =========================================================
echo Sniffy firmware updater
echo (c) 2022 SDR Engineering - onderdeel van Solardoctor B.V.
echo =========================================================
echo.
echo Steps to update:
echo 1) Connect module via USB with your computer.
echo 2) Wait for your computer to install the appropriate USB drivers for the device.
echo 3) If your module has a programming (PROG) button (located next to the USB port), additionally connect a 12V adapter.
echo    Then, keep PROG-button pressed and briefly press the reset button while holding PROG.
echo    The LED should go to a very dim green. Release all buttons, the module is now in firmware update mode.
echo    Note: skip this step if your module does not have a programming (PROG) button. Simply plug in USB-C and continue to step 4.
echo 4) Press [ENTER] to start flashing, or enter the COM-port to skip the search.
echo 5) The updater will search for the correct COM-port, and might try them all. Just have some patience.
echo.
echo Warning: updating the firmware will erase the configuration of the module.
echo Warning: do not disconnect the module from 12V power or from your computer while updating
echo Warning: this firmware updater is only compatible with board version R05 and later
echo.
echo.

:PRG
set COMPORT=
set /p COMPORT=COM-port of module (leave empty to search):

IF [%COMPORT%] == [] GOTO NOCOM

:COM_DETECTED
echo Updating firmware...
.\esptool.exe --chip esp32 --baud 921600 --port %COMPORT% --before usb_reset --after hard_reset write_flash --flash_mode dio --flash_freq 80m --flash_size 4MB 0x0000 .\firmware.bin
GOTO DONE

:NOCOM
echo Searching for COM-port...
set COMPORT=
for /f "usebackq" %%B in (`wmic path Win32_SerialPort Where "PNPDeviceID LIKE '%%VID_303A&PID_1001%%'" Get DeviceID ^| FIND "COM"`) do set COMPORT=%%B
IF [%COMPORT%] == [] GOTO TRYALL

echo COM-port is detected as %COMPORT%
GOTO COM_DETECTED

:TRYALL
echo Automatic detection failed. Trying all COM-ports, this might take a while...
echo.
.\esptool.exe --chip esp32 --baud 921600 --before usb_reset --after hard_reset write_flash --flash_mode dio --flash_freq 80m --flash_size 4MB 0x0000 .\firmware.bin


IF ERRORLEVEL 1 GOTO PRGERROR

call soundplayer.bat "C:\Windows\Media\Windows Ding.wav"

:PRGSUCCES
echo.
echo Done.
goto DONE

:PRGERROR
echo.
echo ! ! ! Error occured during flasing ! ! !
pause

:DONE
echo.
set /p Q=Flash another module? (y/[n])

IF "%Q%" == "y" GOTO PRG

pause
